/*
 * carddeck is an implementation of a deck of cards.
 *
 * Copyright (C) 2008 Thomas Repantis <trep@cs.ucr.edu>
 * 
 * This file is part of carddeck.
 *
 * carddeck is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * carddeck is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with carddeck.  If not, see <http://www.gnu.org/licenses/>.
 */

//
//! \author Thomas Repantis
//! \file Card.h
//! Carddeck is an implementation of a deck of cards.
//

#ifndef __CARD_H__
#define __CARD_H__

#include <string>
#include "Exception.h"

namespace deck {

  //! Card is an abstract representation of a card.
  class Card {
  public:
    //! Types of decks, standard 52-card deck is supported.
    enum SuitType { 
      CLUB = 1, 
      DIAMOND, 
      HEART, 
      SPADE
    };
    
    Card(int rank, enum SuitType suit) throw(error::Exception);
    //!< Card constructor.
    
    virtual ~Card();
    //!< Card destructor.

    virtual std::string view() const = 0;
    //!< View the name of the card.
    // The way the name is printed differs between 
    // cards with letters and cards with numbers.

  protected:
    int rank_;
    //!< The rank of the card.  Can be from 1 to 13.

    enum SuitType suit_;
    //!< The suit of the card.  Can be one of CLUB, DIAMOND, HEART, SPADE.

  private:

  };

  inline std::ostream &operator<<(std::ostream &out, const Card &card) {
    return out << card.view();
  }
  //!< Print the name of the card.

}

#endif
