/*
 * carddeck is an implementation of a deck of cards.
 *
 * Copyright (C) 2008 Thomas Repantis <trep@cs.ucr.edu>
 * 
 * This file is part of carddeck.
 *
 * carddeck is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * carddeck is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with carddeck.  If not, see <http://www.gnu.org/licenses/>.
 */

//
//! \author Thomas Repantis
//! \file CardFactory.h
//! Carddeck is an implementation of a deck of cards.
//

#ifndef __CARDFACTORY_H__
#define __CARDFACTORY_H__

#include <iostream>
#include "Exception.h"
#include "Card.h"
#include "NumberCard.h"
#include "LetterCard.h"

namespace deck {

  //! CardFactory creates cards of the given card type.
  //! We use the factory method design pattern.
  template <typename cardType>
  class CardFactory {
  public:
    CardFactory() {};
    //!< CardFactory constructor.
    
    virtual ~CardFactory() {};
    //!< CardFactory destructor.

    virtual Card *createCard(int rank, enum Card::SuitType suit) {
      Card *pCard = NULL;
      try {
	pCard = new cardType(rank, suit);
      }
      catch (error::Exception &e) {
	std::cout << e << std::endl;
      }
      return pCard;
    }
    //!< Create a card.
    
  private:
    
  };
}

#endif
