/*
 * carddeck is an implementation of a deck of cards.
 *
 * Copyright (C) 2008 Thomas Repantis <trep@cs.ucr.edu>
 * 
 * This file is part of carddeck.
 *
 * carddeck is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * carddeck is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with carddeck.  If not, see <http://www.gnu.org/licenses/>.
 */

//
//! \author Thomas Repantis
//! \file DeckTest.cc
//! Carddeck is an implementation of a deck of cards.
//

#include "DeckTest.h"

using namespace test;

//! DeckTest constructor.
DeckTest::DeckTest() {
  try {
    pDeck_ = new deck::Deck();
  }
  catch (error::Exception &e) {
    std::cout << e << std::endl;
  }
  interactWithUser_();
}

//! DeckTest destructor.
DeckTest::~DeckTest() {
  delete pDeck_;
}

//! Print the choices the user has when interacting with the program.
void DeckTest::printUserChoices_()
{
  std::cout <<
    "Available options: \n" <<
    "d deals a card\n" <<
    "s shuffles the deck\n" <<
    "v views the cards left on the deck\n" <<
    "r resets the deck\n" <<
    "h prints this help message\n" <<
    "q quits the program\n";
}

//! Get the choices of the user and execute them.
void DeckTest::interactWithUser_() {

  printUserChoices_();
  
  bool done = false;
  while (!done) {
    std::cout << "Please enter your choice: ";
    
    char choice;
    std::cin >> choice;
    
    switch (choice) {
      case 'd': {
	  std::cout << "Dealing a card: " << std::endl;
	  deck::Card *pCard = NULL;
	  try {
	    pCard = pDeck_->deal();
	    std::cout << *pCard << std::endl;
	  }
	  catch (error::Exception &e) {
	    std::cout << e << std::endl;
	  }
	}
	break;

      case 's': {
	  std::cout << "Shuffling the deck: " << std::endl;
	  pDeck_->shuffle();
	  std::cout << "Done shuffling." << std::endl;
	}
	break;

      case 'v': {
	  std::cout << "Viewing the deck: " << std::endl;
	  std::cout << *pDeck_ << std::endl;
	}
	break;
	
      case 'r': {
	  std::cout << "Resetting the deck: " << std::endl;
	  pDeck_->reset();
	  std::cout << "Done resetting." << std::endl;
	}
	break;

      case 'h': {
	  printUserChoices_();
	}
	break;

      case 'q': {
	  done = true;
	}
	break;
	
      default:
	; // Continue looping.
      }
  }
}

//! Takes the command line arguments and creates an instance of the simulator.
int main(int argc, char* argv[])
{
  if(argc != (CLI_ARG_NUM_ + 1)) // Arguments + the executable's name.
    {
      std::cerr << "Usage: " 
		<< argv[0] 
		<< std::endl;
      exit(1); // Error.
    } 

  std::cout << "This program comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome to redistribute it under certain conditions. carddeck is licensed under the GNU General Public License. See the file COPYING for details.\n\n"
	    << "carddeck - an implementation of a deck of cards\n"
	    << "Copyright (C) 2008 Thomas Repantis <trep@cs.ucr.edu>\n\n";
  
  DeckTest *deckTest = new DeckTest();

  delete deckTest;

  exit(0); // Success.
} 

