/*
 * carddeck is an implementation of a deck of cards.
 *
 * Copyright (C) 2008 Thomas Repantis <trep@cs.ucr.edu>
 * 
 * This file is part of carddeck.
 *
 * carddeck is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * carddeck is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with carddeck.  If not, see <http://www.gnu.org/licenses/>.
 */

//
//! \author Thomas Repantis
//! \file Exception.h
//! Carddeck is an implementation of a deck of cards.
//

#ifndef __EXCEPTION_H__
#define __EXCEPTION_H__

#include <string>

namespace error {

  //! Exception is raised if a run-time error occurs.
  class Exception {
  public:
    Exception(const std::string &error) : errorMessage_(error) {};
    //!< Exception constructor.
    
    ~Exception() {};
    //!< Exception destructor.

    std::string getError() const { return errorMessage_; }
    //!< Get the exception message.

  private:
    std::string errorMessage_;
    //!< The error that caused the exception.

  };

  inline std::ostream &operator<<(std::ostream &out, const Exception &e) {
    return out << e.getError();       
  }
  //!< Print the error that caused the exception.
  
}

#endif

