/*
 * carddeck is an implementation of a deck of cards.
 *
 * Copyright (C) 2008 Thomas Repantis <trep@cs.ucr.edu>
 * 
 * This file is part of carddeck.
 *
 * carddeck is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * carddeck is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with carddeck.  If not, see <http://www.gnu.org/licenses/>.
 */

//
//! \author Thomas Repantis
//! \file LetterCard.cc
//! Carddeck is an implementation of a deck of cards.
//

#include "LetterCard.h"

using namespace deck;

//! LetterCard constructor.
LetterCard::LetterCard(int rank, enum SuitType suit) throw(error::Exception) 
  : Card(rank, suit) {
  if ((rank != 1) && (rank != 11) && (rank != 12) && (rank != 13)) {
    throw error::Exception("Invalid letter card type.");
  }

}

//! LetterCard destructor.
LetterCard::~LetterCard() {
}

//!< View the name of the card.
// The name of the card is identifying the card uniquely, 
// as in "rank of suit".
std::string LetterCard::view() const {
  std::string name;
  
  if (rank_ == 1) {
    name += "ace";
  }
  if (rank_ == 11) {
    name += "jack";
  }
  if (rank_ == 12) {
    name += "queen";
  }
  if (rank_ == 13) {
    name += "king";
  }

  name += " of ";
  if (suit_ == CLUB) {
    name += "clubs";
  }
  if (suit_ == DIAMOND) {
    name += "diamonds";
  }
  if (suit_ == HEART) {
    name += "hearts";
  }
  if (suit_ == SPADE) {
    name += "spades";
  }

  return name;
}

