/*
 * carddeck is an implementation of a deck of cards.
 *
 * Copyright (C) 2008 Thomas Repantis <trep@cs.ucr.edu>
 * 
 * This file is part of carddeck.
 *
 * carddeck is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * carddeck is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with carddeck.  If not, see <http://www.gnu.org/licenses/>.
 */

//
//! \author Thomas Repantis
//! \file NumberCard.cc
//! Carddeck is an implementation of a deck of cards.
//

#include "NumberCard.h"

using namespace deck;

//! NumberCard constructor.
NumberCard::NumberCard(int rank, enum SuitType suit) throw(error::Exception) 
  : Card(rank, suit) {
  if ((rank < 2) || (rank > 10)) {
    throw error::Exception("Invalid number card type.");
  }

}

//! NumberCard destructor.
NumberCard::~NumberCard() {
}

//!< View the name of the card.
// The name of the card is identifying the card uniquely, 
// as in "rank of suit".
std::string NumberCard::view() const {
  std::string name;
  
  std::ostringstream o;
  o << rank_;
  std::string rank(o.str());
  name += rank;
  name += " of ";
  if (suit_ == CLUB) {
    name += "clubs";
  }
  if (suit_ == DIAMOND) {
    name += "diamonds";
  }
  if (suit_ == HEART) {
    name += "hearts";
  }
  if (suit_ == SPADE) {
    name += "spades";
  }

  return name;
}


